@@ -4,8 +4,8 @@ from datetime import datetime
 from os import remove
 from os.path import join
 from shutil import copyfile
+from tempfile import gettempdir
 
-import pytest
 from sqlalchemy import select
 from sqlalchemy.orm.decl_api import DeclarativeAttributeIntercept
 
@@ -13,30 +13,22 @@ from hdx.database import Database
 
 
 class TestReflect:
-    dbpath = join("tests", "test_database.db")
-    testdb = join("tests", "fixtures", "test.db")
-
-    @pytest.fixture(scope="function")
-    def database_to_reflect(self):
-        try:
-            remove(TestReflect.dbpath)
-            copyfile(TestReflect.testdb, TestReflect.dbpath)
-        except OSError:
-            pass
-        return f"sqlite:///{TestReflect.dbpath}"
-
-    def test_get_reflect_session(self, database_to_reflect):
+    def test_get_reflect_session(self):
+        dbpath = join(gettempdir(), "test_reflect.db")
+        testdb = join("tests", "fixtures", "test.db")
+        copyfile(testdb, dbpath)
         with Database(
-            database=TestReflect.dbpath,
+            database=dbpath,
             port=None,
             dialect="sqlite",
             reflect=True,
         ) as dbdatabase:
             dbengine = dbdatabase.get_engine()
-            assert str(dbengine.url) == "sqlite:///tests/test_database.db"
+            dburi = f"sqlite:///{dbpath}"
+            assert str(dbengine.url) == dburi
             dbsession = dbdatabase.get_session()
             assert isinstance(dbdatabase.base, DeclarativeAttributeIntercept)
-            assert str(dbsession.bind.engine.url) == database_to_reflect
+            assert str(dbsession.bind.engine.url) == dburi
             Table1 = dbdatabase.get_reflected_classes().table1
             row = dbsession.execute(select(Table1)).scalar_one()
             assert row.id == "1"
@@ -44,3 +36,4 @@ class TestReflect:
             # with reflection, type annotation maps do not work and hence
             # we don't have a timezone here
             assert row.date1 == datetime(1993, 9, 23, 14, 12, 56, 111000)
+        remove(dbpath)
